@@ -16,11 +16,13 @@ TextAutoGenerateAttachmentTest::TextAutoGenerateAttachmentTest(QObject *parent)
 void TextAutoGenerateAttachmentTest::shouldHaveDefaultValues()
 {
     const TextAutoGenerateText::TextAutoGenerateAttachment att;
-    QVERIFY(att.base64().isEmpty());
+    QVERIFY(att.content().isEmpty());
     QVERIFY(att.mimeType().isEmpty());
     QVERIFY(att.name().isEmpty());
     QCOMPARE(att.attachmentType(), TextAutoGenerateText::TextAutoGenerateAttachment::AttachmentType::Unknown);
     QVERIFY(!att.isValid());
+    QVERIFY(att.showAttachment());
+    QVERIFY(att.attachmentId().isEmpty());
 }
 
 #include "moc_textautogenerateattachmenttest.cpp"
