@@ -27,15 +27,18 @@ void TextAutoGenerateMessageTest::shouldHaveDefaultValues()
     QVERIFY(!msg.inProgress());
     QVERIFY(!msg.editingMode());
     QVERIFY(!msg.mouseHover());
+    QVERIFY(!msg.textToSpeechInProgress());
     QVERIFY(msg.uuid().isEmpty());
     QVERIFY(msg.answerUuid().isEmpty());
     QVERIFY(msg.engineName().isEmpty());
     QVERIFY(msg.modelName().isEmpty());
     QVERIFY(msg.instanceName().isEmpty());
     QVERIFY(msg.tools().isEmpty());
+    QCOMPARE(msg.numberOfTextSearched(), -1);
+    QVERIFY(!msg.messageAttachments());
 
     // 10/05/2025 => size 224
-    QCOMPARE(sizeof(TextAutoGenerateText::TextAutoGenerateMessage), 152);
+    QCOMPARE(sizeof(TextAutoGenerateText::TextAutoGenerateMessage), 160);
 }
 
 void TextAutoGenerateMessageTest::shouldCheckFromString()
@@ -57,6 +60,7 @@ void TextAutoGenerateMessageTest::shouldParseMessage_data()
         firstMessageRef.setUuid("79aa1eac872647a2ac12cb56ddd00e1f");
         firstMessageRef.setContent(u"test1"_s);
         firstMessageRef.setSender(TextAutoGenerateText::TextAutoGenerateMessage::Sender::User);
+        firstMessageRef.generateHtml();
 
         QTest::addRow("test1user") << u"test1user"_s << firstMessageRef;
     }
@@ -67,6 +71,7 @@ void TextAutoGenerateMessageTest::shouldParseMessage_data()
         firstMessageLlmRef.setUuid("136ccbbe9e1e4d6a90c6b9917daf9a29");
         firstMessageLlmRef.setContent(u"test llm"_s);
         firstMessageLlmRef.setSender(TextAutoGenerateText::TextAutoGenerateMessage::Sender::Assistant);
+        firstMessageLlmRef.generateHtml();
         TextAutoGenerateText::TextAutoGenerateAnswerInfo info;
         info.setEngineName(u"openai"_s);
         info.setInstanceName(u"test openai"_s);
@@ -102,6 +107,7 @@ void TextAutoGenerateMessageTest::shouldSerializeMessage()
         firstMessageRef.setUuid("79aa1eac872647a2ac12cb56ddd00e1f");
         firstMessageRef.setContent(u"test1"_s);
         firstMessageRef.setSender(TextAutoGenerateText::TextAutoGenerateMessage::Sender::User);
+        firstMessageRef.generateHtml();
 
         const QByteArray ba = TextAutoGenerateText::TextAutoGenerateMessage::serialize(firstMessageRef);
         const TextAutoGenerateText::TextAutoGenerateMessage output =
@@ -115,6 +121,7 @@ void TextAutoGenerateMessageTest::shouldSerializeMessage()
         firstMessageLlmRef.setUuid("136ccbbe9e1e4d6a90c6b9917daf9a29");
         firstMessageLlmRef.setContent(u"test llm"_s);
         firstMessageLlmRef.setSender(TextAutoGenerateText::TextAutoGenerateMessage::Sender::Assistant);
+        firstMessageLlmRef.generateHtml();
         TextAutoGenerateText::TextAutoGenerateAnswerInfo info;
         info.setEngineName(u"openai"_s);
         info.setInstanceName(u"test openai"_s);
@@ -125,6 +132,44 @@ void TextAutoGenerateMessageTest::shouldSerializeMessage()
             TextAutoGenerateText::TextAutoGenerateMessage::deserialize(QCborValue::fromCbor(ba).toMap().toJsonObject());
         QCOMPARE(firstMessageLlmRef, output);
     }
+
+    {
+        TextAutoGenerateText::TextAutoGenerateMessage firstMessageRef;
+        firstMessageRef.setAnswerUuid("b84a362695c34e5491b54e414192fb70");
+        firstMessageRef.setDateTime(1753338999);
+        firstMessageRef.setUuid("79aa1eac872647a2ac12cb56ddd00e1f");
+        firstMessageRef.setContent(u"test1"_s);
+        firstMessageRef.setSender(TextAutoGenerateText::TextAutoGenerateMessage::Sender::User);
+        firstMessageRef.generateHtml();
+
+        TextAutoGenerateText::TextAutoGenerateAttachments t;
+        QList<TextAutoGenerateText::TextAutoGenerateAttachment> list;
+        {
+            TextAutoGenerateText::TextAutoGenerateAttachment att;
+            att.setContent("sdfsdf"_ba);
+            att.setMimeType("mp4");
+            att.setName(u"foo"_s);
+            att.setAttachmentId("idttt"_ba);
+            att.setAttachmentType(TextAutoGenerateText::TextAutoGenerateAttachment::AttachmentType::Audio);
+            list.append(att);
+        }
+        {
+            TextAutoGenerateText::TextAutoGenerateAttachment att;
+            att.setContent("foo11"_ba);
+            att.setMimeType("doc");
+            att.setName(u"foo2"_s);
+            att.setAttachmentId("idttt2"_ba);
+            att.setAttachmentType(TextAutoGenerateText::TextAutoGenerateAttachment::AttachmentType::File);
+            list.append(att);
+        }
+        t.setMessageAttachments(list);
+        firstMessageRef.setMessageAttachments(t);
+
+        const QByteArray ba = TextAutoGenerateText::TextAutoGenerateMessage::serialize(firstMessageRef);
+        const TextAutoGenerateText::TextAutoGenerateMessage output =
+            TextAutoGenerateText::TextAutoGenerateMessage::deserialize(QCborValue::fromCbor(ba).toMap().toJsonObject());
+        QCOMPARE(firstMessageRef, output);
+    }
 }
 
 // TODO add image support
