@@ -5,7 +5,6 @@
 */
 
 #include "textautogeneratelocaldatabaseabstract.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "textautogeneratetextcore_database_debug.h"
 
@@ -13,6 +12,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QSqlError>
 #include <QSqlQuery>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace TextAutoGenerateText;
 TextAutoGenerateLocalDatabaseAbstract::TextAutoGenerateLocalDatabaseAbstract(const QString &basePath, DatabaseType type)
     : mBasePath(basePath)
@@ -53,6 +53,9 @@ QString TextAutoGenerateLocalDatabaseAbstract::databaseName() const
     case DatabaseType::Messages:
         prefix = u"messages"_s;
         break;
+    case DatabaseType::PendingTypedInfo:
+        prefix = u"pendingtypedinfo"_s;
+        break;
     }
     return prefix;
 }
