@@ -8,11 +8,14 @@
 
 #include "textautogeneratelocalchatsdatabase.h"
 #include "textautogeneratelocalmessagesdatabase.h"
+#include "textautogeneratelocalroompendingtypedinfodatabase.h"
 
 using namespace TextAutoGenerateText;
+using namespace Qt::Literals::StringLiterals;
 TextAutoGenerateLocalDatabaseManager::TextAutoGenerateLocalDatabaseManager()
     : mMessagesDatabase(std::make_unique<TextAutoGenerateLocalMessagesDatabase>())
     , mChatsDatabase(std::make_unique<TextAutoGenerateLocalChatsDatabase>())
+    , mRoomPendingTypedInfoDatabase(std::make_unique<TextAutoGenerateLocalRoomPendingTypedInfoDatabase>())
 {
 }
 
@@ -28,6 +31,17 @@ QList<TextAutoGenerateChat> TextAutoGenerateLocalDatabaseManager::loadChats() co
     return mChatsDatabase->loadChats();
 }
 
+QStringList TextAutoGenerateLocalDatabaseManager::chatsList() const
+{
+    QStringList lst;
+    const QList<TextAutoGenerateChat> chats = loadChats();
+    lst.reserve(chats.count());
+    for (const auto &chat : chats) {
+        lst.append(u"%1 (%2)"_s.arg(chat.title(), QString::fromLatin1(chat.identifier())));
+    }
+    return lst;
+}
+
 QList<TextAutoGenerateSearchMessage> TextAutoGenerateLocalDatabaseManager::searchTextInDatabase(const QList<QByteArray> &listIds, const QString &searchText)
 {
     QList<TextAutoGenerateSearchMessage> lst;
@@ -58,3 +72,19 @@ void TextAutoGenerateLocalDatabaseManager::insertOrUpdateChat(const TextAutoGene
 {
     mChatsDatabase->insertOrUpdateChat(chat);
 }
+
+void TextAutoGenerateLocalDatabaseManager::updateRoomPendingTypedInfo(const QByteArray &chatIdentifier,
+                                                                      const TextAutoGenerateChatSettings::PendingTypedInfo &pendingTypedInfo)
+{
+    mRoomPendingTypedInfoDatabase->updateRoomPendingTypedInfo(chatIdentifier, pendingTypedInfo);
+}
+
+void TextAutoGenerateLocalDatabaseManager::deleteRoomPendingTypedInfo(const QByteArray &chatIdentifier)
+{
+    mRoomPendingTypedInfoDatabase->deleteRoomPendingTypedInfo(chatIdentifier);
+}
+
+QMap<QByteArray /*RoomId*/, TextAutoGenerateChatSettings::PendingTypedInfo> TextAutoGenerateLocalDatabaseManager::loadRoomPendingTypedInfo() const
+{
+    return mRoomPendingTypedInfoDatabase->loadRoomPendingTypedInfo();
+}
