@@ -5,7 +5,6 @@
 */
 
 #include "textautogeneratelocalmessagesdatabase.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "core/textautogeneratesearchmessageutils.h"
 #include "textautogeneratelocaldatabaseutils.h"
@@ -23,6 +22,7 @@ enum class MessagesFields {
     TimeStamp,
     Json,
 }; // in the same order as the table
+using namespace Qt::Literals::StringLiterals;
 using namespace TextAutoGenerateText;
 TextAutoGenerateLocalMessagesDatabase::TextAutoGenerateLocalMessagesDatabase()
     : TextAutoGenerateLocalDatabaseAbstract(TextAutoGenerateLocalDatabaseUtils::localMessagesDatabasePath(),
@@ -142,7 +142,10 @@ QList<TextAutoGenerateMessage> TextAutoGenerateLocalMessagesDatabase::loadMessag
     Q_ASSERT(db.isOpen());
     const QString query = TextAutoGenerateLocalMessagesDatabase::generateQueryStr();
     QSqlQuery resultQuery(db);
-    resultQuery.prepare(query);
+    if (!resultQuery.prepare(query)) {
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_DATABASE_LOG) << " Invalid query" << query << " resultQuery " << resultQuery.lastError().text();
+        return {};
+    }
     if (!resultQuery.exec()) {
         qCWarning(TEXTAUTOGENERATETEXT_CORE_DATABASE_LOG) << " Impossible to execute query: " << resultQuery.lastError() << " query: " << query;
         return {};
