@@ -9,17 +9,31 @@
 #include <QSortFilterProxyModel>
 namespace TextAutoGenerateText
 {
+/**
+ * @brief The TextAutoGenerateTextInstanceSortFilterProxyModel class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class TEXTAUTOGENERATETEXT_EXPORT TextAutoGenerateTextInstanceSortFilterProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
+    /*!
+     */
     explicit TextAutoGenerateTextInstanceSortFilterProxyModel(QObject *parent = nullptr);
+    /*!
+     */
     ~TextAutoGenerateTextInstanceSortFilterProxyModel() override;
 
-    QString searchText() const;
+    /*!
+     */
+    [[nodiscard]] QString searchText() const;
+    /*!
+     */
     void setSearchText(const QString &newSearchText);
 
 protected:
+    /*!
+     */
     [[nodiscard]] bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
