@@ -4,12 +4,12 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "textautogeneratemanager.h"
-#include "config-textautogeneratetext.h"
 #include "core/localdatabase/textautogeneratelocaldatabasemanager.h"
 #include "core/models/textautogeneratechatsmodel.h"
 #include "core/models/textautogeneratemessagesmodel.h"
+#include "core/textautogeneratefilecache.h"
 #include "core/textautogeneratesettings.h"
-#include "core/tools/textautogeneratetexttoolplugin.h"
+#include "core/textautogeneratetoolcalljob.h"
 #include "core/tools/textautogeneratetexttoolpluginmanager.h"
 #include "textautogeneratechatsettings.h"
 #include "textautogenerateengineloader.h"
@@ -22,6 +22,10 @@
 #include "textautogeneratemanageradaptor.h"
 #include <QDBusConnection>
 #endif
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#include "core/texttospeech/textautogeneratetexttospeechenqueuemanager.h"
+#include <TextEditTextToSpeech/TextToSpeech>
+#endif
 
 #include <KLocalizedString>
 using namespace Qt::Literals::StringLiterals;
@@ -43,14 +47,20 @@ TextAutoGenerateManager::TextAutoGenerateManager(QObject *parent)
     : QObject{parent}
     , mTextAutoGenerateChatsModel(new TextAutoGenerateChatsModel(this))
     , mDatabaseManager(new TextAutoGenerateLocalDatabaseManager)
-    , mTextAutoGenerateChatSettings(new TextAutoGenerateChatSettings)
+    , mTextAutoGenerateChatSettings(new TextAutoGenerateChatSettings(this))
+    , mTextAutoGenerateFileCache(new TextAutoGenerateFileCache)
     , mTextAutoGenerateTextInstancesManager(new TextAutoGenerateTextInstancesManager(this, this))
     , mTextAutoGenerateSettings(new TextAutoGenerateSettings())
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    , mTextAutoGenerateTextToSpeechEnqueueManager(new TextAutoGenerateTextToSpeechEnqueueManager(this))
+#endif
 {
     mTextAutoGenerateChatsModel->setTextAutoGenerateChatSettings(mTextAutoGenerateChatSettings.get());
     // Load TextAutoGenerateTextToolPluginManager
     (void)TextAutoGenerateTextToolPluginManager::self();
 
+    mDebug = !qEnvironmentVariableIsEmpty("TEXTAUTOGENERATE_DEBUGGING");
+
 #if HAVE_KTEXTADDONS_TEXTAUTOGENERATE_DBUS_SUPPORT
     new TextAutoGenerateManagerAdaptor(this);
 
@@ -77,11 +87,13 @@ TextAutoGenerateManager::TextAutoGenerateManager(QObject *parent)
             });
     connect(this, &TextAutoGenerateManager::configChanged, this, &TextAutoGenerateManager::loadEngine);
     mTextAutoGenerateSettings->load();
-    const QList<TextAutoGenerateTextToolPlugin *> lstPlugins = TextAutoGenerateTextToolPluginManager::self()->pluginsList();
-    for (const auto p : lstPlugins) {
-        connect(p, &TextAutoGenerateTextToolPlugin::finished, this, &TextAutoGenerateManager::slotPluginFinished);
-        connect(p, &TextAutoGenerateTextToolPlugin::toolInProgress, this, &TextAutoGenerateManager::toolInProgress);
-    }
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    connect(TextEditTextToSpeech::TextToSpeech::self(),
+            &TextEditTextToSpeech::TextToSpeech::aboutToSynthesize,
+            this,
+            &TextAutoGenerateManager::slotAboutToSynthesizeChanged);
+#endif
+    mTextAutoGenerateChatSettings->loadRoomPendingTypedInfo();
 }
 
 TextAutoGenerateManager::~TextAutoGenerateManager()
@@ -163,9 +175,9 @@ void TextAutoGenerateManager::askToAssistant(const QString &msg)
     }
 }
 
-void TextAutoGenerateManager::ask(const QString &msg)
+void TextAutoGenerateManager::ask(const TextAutoGenerateText::TextAutoGenerateManager::AskMessageInfo &info)
 {
-    Q_EMIT askMessageRequested(msg);
+    Q_EMIT askMessageRequested(info);
 }
 
 void TextAutoGenerateManager::createNewChat(const QString &title)
@@ -201,11 +213,12 @@ QStringList TextAutoGenerateManager::chatsList() const
 
 void TextAutoGenerateManager::replaceContent(const QByteArray &chatId,
                                              const QByteArray &uuid,
-                                             const TextAutoGenerateText::TextAutoGenerateReply::Response &content)
+                                             const TextAutoGenerateText::TextAutoGenerateReply::Response &content,
+                                             const QList<TextAutoGenerateAttachmentUtils::AttachmentElementInfo> &attachementInfoList)
 {
     auto messagesModel = messagesModelFromChatId(chatId);
     if (messagesModel) {
-        messagesModel->replaceContent(uuid, content.response); // TODO use tools
+        messagesModel->replaceContent(uuid, content.response, attachementInfoList); // TODO use tools
     } else {
         qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to find model for " << chatId;
     }
@@ -214,7 +227,7 @@ void TextAutoGenerateManager::replaceContent(const QByteArray &chatId,
 bool TextAutoGenerateManager::chatInProgress(const QByteArray &chatId) const
 {
     if (chatId.isEmpty()) {
-        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << " chatid is empty it's a bug!!!!";
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "TextAutoGenerateManager::chatInProgress chatid is empty it's a bug!!!!";
         return false;
     }
     return textAutoGenerateChatsModel()->chatInProgress(chatId);
@@ -269,13 +282,12 @@ void TextAutoGenerateManager::setSaveInDatabase(bool newSaveInDatabase)
 
 void TextAutoGenerateManager::callTools(const QByteArray &chatId, const QByteArray &uuid, const QList<TextAutoGenerateReply::ToolCallArgumentInfo> &info)
 {
-    qDebug() << "TextAutoGenerateManager::callTools chatId : " << chatId << " uuid : " << uuid << " info: " << info;
-    for (const auto &i : info) {
-        auto plugin = TextAutoGenerateTextToolPluginManager::self()->pluginFromToolNameId(i.toolName);
-        if (plugin) {
-            plugin->callTools(chatId, uuid, info);
-        }
-    }
+    auto job = new TextAutoGenerateToolCallJob(chatId, uuid, info, this);
+    connect(job, &TextAutoGenerateToolCallJob::finished, this, &TextAutoGenerateManager::slotPluginFinished);
+    connect(job, &TextAutoGenerateToolCallJob::toolInProgress, this, &TextAutoGenerateManager::toolInProgress);
+    job->start();
+
+    // qDebug() << "TextAutoGenerateManager::callTools chatId : " << chatId << " uuid : " << uuid << " info: " << info;
 }
 
 void TextAutoGenerateManager::changeInProgress(const QByteArray &chatId, const QByteArray &uuid, bool inProgress)
@@ -517,7 +529,7 @@ void TextAutoGenerateManager::checkInitializedMessagesModel()
 TextAutoGenerateMessagesModel *TextAutoGenerateManager::messagesModelFromChatId(const QByteArray &chatId) const
 {
     if (chatId.isEmpty()) {
-        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << " chatid is empty it's a bug!!!!";
+        qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "TextAutoGenerateManager::messagesModelFromChatId chatid is empty it's a bug!!!!";
         return nullptr;
     }
     return textAutoGenerateChatsModel()->messagesModel(chatId);
@@ -607,13 +619,87 @@ void TextAutoGenerateManager::slotChatListChanged([[maybe_unused]] const QString
 #endif
 }
 
-void TextAutoGenerateManager::slotPluginFinished(const QString &str, const QByteArray &messageUuid, const QByteArray &chatId, const QByteArray &toolIdentifier)
+void TextAutoGenerateManager::slotPluginFinished(const TextAutoGenerateText::TextAutoGenerateTextToolPlugin::TextToolPluginInfo &info)
 {
     TextAutoGenerateText::TextAutoGenerateReply::Response content;
-    content.response = str;
+    content.response = info.content;
     // content.info =
-    replaceContent(chatId, messageUuid, content);
-    changeInProgress(chatId, messageUuid, false);
+    replaceContent(info.chatId, info.messageUuid, content, info.attachementInfoList);
+    changeInProgress(info.chatId, info.messageUuid, false);
+}
+
+TextAutoGenerateLocalDatabaseManager *TextAutoGenerateManager::databaseManager() const
+{
+    return mDatabaseManager.get();
+}
+
+QString TextAutoGenerateManager::generateAttachmentTemporaryFile(const QByteArray &attachmentId) const
+{
+    return mTextAutoGenerateFileCache->cacheFilePath(attachmentId);
+}
+
+void TextAutoGenerateManager::setDebug(bool newDebug)
+{
+    mDebug = newDebug;
+}
+
+bool TextAutoGenerateManager::debug() const
+{
+    return mDebug;
+}
+
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+TextAutoGenerateTextToSpeechEnqueueManager *TextAutoGenerateManager::textAutoGenerateTextToSpeechEnqueueManager() const
+{
+    return mTextAutoGenerateTextToSpeechEnqueueManager;
+}
+#endif
+
+void TextAutoGenerateManager::slotAboutToSynthesizeChanged(qsizetype previousId, qsizetype currentId)
+{
+    // qDebug() << " previousId " << previousId << " currentId " << currentId;
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    if (previousId != -1) {
+        const TextAutoGenerateTextToSpeechEnqueueInfo info = mTextAutoGenerateTextToSpeechEnqueueManager->value(previousId);
+        if (info.isValid()) {
+            auto messagesModel = messagesModelFromChatId(info.chatId());
+            if (messagesModel) {
+                messagesModel->changeTextToSpeechInProgress(info.messageId(), false);
+            } else {
+                qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to find model for " << info.chatId();
+            }
+        }
+        // qDebug() << " enqueue list " << mTextAutoGenerateTextToSpeechEnqueueManager->enqueueList() << "previousId " << previousId;
+    }
+    if (currentId != -1) {
+        const TextAutoGenerateTextToSpeechEnqueueInfo info = mTextAutoGenerateTextToSpeechEnqueueManager->value(currentId);
+        if (info.isValid()) {
+            auto messagesModel = messagesModelFromChatId(info.chatId());
+            if (messagesModel) {
+                messagesModel->changeTextToSpeechInProgress(info.messageId(), true);
+            } else {
+                qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to find model for " << info.chatId();
+            }
+            // qDebug() << " enqueue list " << mTextAutoGenerateTextToSpeechEnqueueManager->enqueueList() << "currentId " << currentId;
+        }
+    } else {
+        mTextAutoGenerateTextToSpeechEnqueueManager->clear();
+        // qDebug() << mTextAutoGenerateTextToSpeechEnqueueManager->enqueueList();
+    }
+#endif
+}
+
+QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateManager::AskMessageInfo &t)
+{
+    d.space() << "message:" << t.message;
+    d.space() << "attachments:" << t.attachments;
+    d.space() << "tools:" << t.tools;
+    return d;
+}
+
+bool TextAutoGenerateText::TextAutoGenerateManager::AskMessageInfo::isValid() const
+{
+    return !message.isEmpty() || !attachments.isEmpty() || !tools.isEmpty();
 }
 
 #include "moc_textautogeneratemanager.cpp"
