@@ -9,10 +9,9 @@
 #include <QObject>
 
 #include "textautogeneratetext_export.h"
-#include <QDebug>
+class QDebug;
 
 #include <QJsonDocument>
-#include <TextAutoGenerateText/TextAutoGenerateTextContext>
 #include <TextAutoGenerateText/TextAutoGenerateTextReplyInfo>
 
 class QNetworkReply;
@@ -31,10 +30,30 @@ class TEXTAUTOGENERATETEXT_EXPORT TextAutoGenerateReply : public QObject
     Q_OBJECT
 
 public:
+    struct TEXTAUTOGENERATETEXT_EXPORT ToolCallArgument {
+        QString keyTool;
+        QString value;
+        [[nodiscard]] bool operator==(const ToolCallArgument &other) const;
+    };
+
+    struct TEXTAUTOGENERATETEXT_EXPORT ToolCallArgumentInfo {
+        QList<ToolCallArgument> toolCallArgument;
+        QByteArray toolName;
+        int index = -1;
+        [[nodiscard]] bool operator==(const ToolCallArgumentInfo &other) const;
+    };
+
+    struct TEXTAUTOGENERATETEXT_EXPORT Response {
+        QList<ToolCallArgumentInfo> info;
+        QString response;
+        [[nodiscard]] bool hasToolCallArguments() const;
+    };
+
     struct DownloadModelInfo {
         quint64 total = 0;
         quint64 completed = 0;
         QString status;
+        QString error;
     };
 
     /**
@@ -51,19 +70,12 @@ public:
         DeleteModel,
         CreateModel,
     };
-    explicit TextAutoGenerateReply(QNetworkReply *netReply, RequestTypes requestType, QObject *parent = nullptr);
-    ~TextAutoGenerateReply() override;
-
-    /**
-     * @brief Get the context token for this response.
-     *
-     * Messages sent by most LLMs have a context identifier that allows you to chain messages into a conversation. To create
-     * such a conversation, you need to take this context object and set it on the next KLLMRequest in the conversation.
-     * KLLMInterface::getCompletion() will use that context object to continue the message thread.
-     *
-     * @return A context object that refers to this response.
+    /*!
      */
-    const TextAutoGenerateText::TextAutoGenerateTextContext &context() const;
+    explicit TextAutoGenerateReply(QNetworkReply *netReply, RequestTypes requestType, QObject *parent = nullptr);
+    /*!
+     */
+    ~TextAutoGenerateReply() override;
 
     /**
      * @brief Get extra information about the reply.
@@ -85,8 +97,13 @@ public:
     const TextAutoGenerateText::TextAutoGenerateReply::RequestTypes &requestType() const;
 
     void cancel();
+    /*!
+     */
+
+    /*!
+     */
+    [[nodiscard]] virtual TextAutoGenerateText::TextAutoGenerateReply::Response readResponse() const = 0;
 
-    [[nodiscard]] virtual QString readResponse() const = 0;
 Q_SIGNALS:
     /**
      * @brief Emits when new content has been added to the response.
@@ -106,21 +123,41 @@ Q_SIGNALS:
      */
     void finished();
 
+    /*!
+     */
+    void canceled();
+
+    /*!
+     */
     void downloadInProgress(const TextAutoGenerateText::TextAutoGenerateReply::DownloadModelInfo &info);
+    /*!
+     */
+    void downloadError(const QString &errorStr);
+
+    /*!
+     */
+    void callTools(const QList<TextAutoGenerateText::TextAutoGenerateReply::ToolCallArgument> &toolsArguments, const QString &toolName);
 
 protected:
+    [[nodiscard]] QList<ToolCallArgumentInfo> parseToolCallsOllama(const QJsonArray &array) const;
+    [[nodiscard]] QList<TextAutoGenerateReply::ToolCallArgumentInfo> parseToolCallsOpenAI(const QJsonArray &array) const;
+
     QNetworkReply *const mReply;
     QByteArray mIncompleteTokens;
 
     QList<QJsonDocument> mTokens;
 
     const RequestTypes mRequestType = RequestTypes::Unknown;
-    // TODO context remove it
-    TextAutoGenerateText::TextAutoGenerateTextContext mContext;
     TextAutoGenerateText::TextAutoGenerateTextReplyInfo mInfo;
 
     qint64 mReceivedSize = 0;
 };
 }
+Q_DECLARE_TYPEINFO(TextAutoGenerateText::TextAutoGenerateReply::ToolCallArgument, Q_RELOCATABLE_TYPE);
 Q_DECLARE_TYPEINFO(TextAutoGenerateText::TextAutoGenerateReply::DownloadModelInfo, Q_RELOCATABLE_TYPE);
+Q_DECLARE_TYPEINFO(TextAutoGenerateText::TextAutoGenerateReply::ToolCallArgumentInfo, Q_RELOCATABLE_TYPE);
+Q_DECLARE_TYPEINFO(TextAutoGenerateText::TextAutoGenerateReply::Response, Q_RELOCATABLE_TYPE);
 TEXTAUTOGENERATETEXT_EXPORT QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateReply::DownloadModelInfo &t);
+TEXTAUTOGENERATETEXT_EXPORT QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateReply::ToolCallArgument &t);
+TEXTAUTOGENERATETEXT_EXPORT QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateReply::ToolCallArgumentInfo &t);
+TEXTAUTOGENERATETEXT_EXPORT QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateReply::Response &t);
