@@ -39,6 +39,8 @@ public:
 
     [[nodiscard]] bool hasVisionSupport() const override;
     [[nodiscard]] bool hasToolsSupport() const override;
+    [[nodiscard]] bool hasOcrSupport() const override;
+    [[nodiscard]] bool hasAudioSupport() const override;
 
 protected:
     void sendToAssistant(const SendToAssistantInfo &info) override;
