@@ -38,9 +38,6 @@ QString GenericNetworkServerInfo::translatedName(GenericNetworkManager::PluginNe
         return i18n("Anthropic");
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return i18n("Kimi (Moonshot AI)");
-    case GenericNetworkManager::PluginNetworkType::LastElement:
-        Q_ASSERT(false);
-        return {};
     }
     return {};
 }
@@ -61,9 +58,6 @@ QString GenericNetworkServerInfo::chatCompletionPath(GenericNetworkManager::Plug
     case GenericNetworkManager::PluginNetworkType::Anthropic:
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return u"chat/completions"_s;
-    case GenericNetworkManager::PluginNetworkType::LastElement:
-        Q_ASSERT(false);
-        return {};
     }
     return {};
 }
@@ -92,9 +86,6 @@ QString GenericNetworkServerInfo::webSite(GenericNetworkManager::PluginNetworkTy
         return u"https://www.anthropic.com/"_s;
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return u"https://www.moonshot.ai/"_s;
-    case GenericNetworkManager::PluginNetworkType::LastElement:
-        Q_ASSERT(false);
-        return {};
     }
     return {};
 }
@@ -123,9 +114,6 @@ QString GenericNetworkServerInfo::apiUrl(GenericNetworkManager::PluginNetworkTyp
         return u"https://api.anthropic.com/v1/"_s;
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return u"https://api.moonshot.ai/v1/"_s;
-    case GenericNetworkManager::PluginNetworkType::LastElement:
-        Q_ASSERT(false);
-        return {};
     }
     return {};
 }
@@ -152,9 +140,6 @@ QString GenericNetworkServerInfo::description(GenericNetworkManager::PluginNetwo
         return i18n("Meta AI Llama API");
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return i18n("Kimi large language models by Moonshot AI");
-    case GenericNetworkManager::PluginNetworkType::LastElement:
-        Q_ASSERT(false);
-        return {};
     }
     return {};
 }
@@ -183,9 +168,6 @@ QString GenericNetworkServerInfo::pluginName(GenericNetworkManager::PluginNetwor
         return u"anthropic"_s;
     case GenericNetworkManager::PluginNetworkType::KimiAI:
         return u"kimiai"_s;
-    case GenericNetworkManager::PluginNetworkType::LastElement:
-        Q_ASSERT(false);
-        return {};
     }
     return {};
 }
@@ -220,7 +202,7 @@ QList<TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer> Generic
 {
     QList<TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer> listInfo;
     for (int i = static_cast<int>(GenericNetworkManager::PluginNetworkType::Unknown) + 1;
-         i < static_cast<int>(GenericNetworkManager::PluginNetworkType::LastElement);
+         i <= static_cast<int>(GenericNetworkManager::PluginNetworkType::LastElement);
          ++i) {
         const TextAutoGenerateText::TextAutoGenerateTextClient::SupportedServer info{
             .localizedName = QStringLiteral("%1 (%2)").arg(
@@ -258,13 +240,70 @@ GenericNetworkServerInfo::Limitations GenericNetworkServerInfo::limitations(Gene
     case GenericNetworkManager::PluginNetworkType::KlusterAI:
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
-    case GenericNetworkManager::PluginNetworkType::LastElement:
         return limits;
     }
     return limits;
 }
 
 bool GenericNetworkServerInfo::hasVisionSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const
+{
+    switch (type) {
+    case GenericNetworkManager::PluginNetworkType::Unknown:
+        qCWarning(AUTOGENERATETEXT_GENERICNETWORK_LOG) << "PluginNetworkType is unknown. It's a bug";
+        return false;
+    case GenericNetworkManager::PluginNetworkType::MistralAI:
+        if (currentModel == "pixtral-12b-latest"_L1 || currentModel == "pixtral-large-latest"_L1 || currentModel == "mistral-medium-2508"_L1
+            || currentModel == "mistral-small-2506"_L1) {
+            return true;
+        }
+        return false;
+    case GenericNetworkManager::PluginNetworkType::LlamaApi:
+    case GenericNetworkManager::PluginNetworkType::OpenAI:
+    case GenericNetworkManager::PluginNetworkType::GroqAI:
+    case GenericNetworkManager::PluginNetworkType::VeniceAI:
+    case GenericNetworkManager::PluginNetworkType::KimiAI:
+    case GenericNetworkManager::PluginNetworkType::KlusterAI:
+    case GenericNetworkManager::PluginNetworkType::CerebrasAI:
+    case GenericNetworkManager::PluginNetworkType::Anthropic:
+        return false;
+    }
+    return false;
+}
+
+bool GenericNetworkServerInfo::hasToolsSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const
+{
+    qDebug() << " bool GenericNetworkServerInfo::hasToolsSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const"
+             << currentModel << " type " << static_cast<int>(type);
+    switch (type) {
+    case GenericNetworkManager::PluginNetworkType::Unknown:
+        qCWarning(AUTOGENERATETEXT_GENERICNETWORK_LOG) << "PluginNetworkType is unknown. It's a bug";
+        return false;
+    case GenericNetworkManager::PluginNetworkType::MistralAI: {
+        // https://docs.mistral.ai/capabilities/function_calling/#tools
+        qDebug() << " currentModel " << currentModel;
+        if (currentModel.startsWith("mistral-large"_L1) || currentModel.startsWith("mistral-medium"_L1) || currentModel.startsWith("mistral-small"_L1)
+            || currentModel.startsWith("magistral-small"_L1) || currentModel.startsWith("magistral-medium"_L1) || currentModel.startsWith("devstral-small"_L1)
+            || currentModel.startsWith("devstral-medium"_L1) || currentModel.startsWith("voxtral-small"_L1) || currentModel.startsWith("voxtral-mini"_L1)
+            || currentModel.startsWith("ministral-8b"_L1) || currentModel.startsWith("ministral-3b"_L1) || currentModel.startsWith("pixtral-12b"_L1)
+            || currentModel.startsWith("pixtral-large"_L1) || currentModel.startsWith("mistral-nemo"_L1) || currentModel.startsWith("codestral"_L1)) {
+            return true;
+        }
+        return false;
+    }
+    case GenericNetworkManager::PluginNetworkType::LlamaApi:
+    case GenericNetworkManager::PluginNetworkType::OpenAI:
+    case GenericNetworkManager::PluginNetworkType::GroqAI:
+    case GenericNetworkManager::PluginNetworkType::VeniceAI:
+    case GenericNetworkManager::PluginNetworkType::KimiAI:
+    case GenericNetworkManager::PluginNetworkType::KlusterAI:
+    case GenericNetworkManager::PluginNetworkType::CerebrasAI:
+    case GenericNetworkManager::PluginNetworkType::Anthropic:
+        return false;
+    }
+    return false;
+}
+
+bool GenericNetworkServerInfo::hasOcrSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
@@ -279,26 +318,18 @@ bool GenericNetworkServerInfo::hasVisionSupport(const QString &currentModel, Gen
     case GenericNetworkManager::PluginNetworkType::KlusterAI:
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
-    case GenericNetworkManager::PluginNetworkType::LastElement:
         return false;
     }
     return false;
 }
 
-bool GenericNetworkServerInfo::hasToolsSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const
+bool GenericNetworkServerInfo::hasAudioSupport(const QString &currentMode, GenericNetworkManager::PluginNetworkType type) const
 {
     switch (type) {
     case GenericNetworkManager::PluginNetworkType::Unknown:
         qCWarning(AUTOGENERATETEXT_GENERICNETWORK_LOG) << "PluginNetworkType is unknown. It's a bug";
         return false;
-    case GenericNetworkManager::PluginNetworkType::MistralAI: {
-        // https://docs.mistral.ai/capabilities/function_calling/#tools
-        qDebug() << " currentModel " << currentModel;
-        if (currentModel == "Mistral Large"_L1) {
-            return true;
-        }
-        return false;
-    }
+    case GenericNetworkManager::PluginNetworkType::MistralAI:
     case GenericNetworkManager::PluginNetworkType::LlamaApi:
     case GenericNetworkManager::PluginNetworkType::OpenAI:
     case GenericNetworkManager::PluginNetworkType::GroqAI:
@@ -307,8 +338,9 @@ bool GenericNetworkServerInfo::hasToolsSupport(const QString &currentModel, Gene
     case GenericNetworkManager::PluginNetworkType::KlusterAI:
     case GenericNetworkManager::PluginNetworkType::CerebrasAI:
     case GenericNetworkManager::PluginNetworkType::Anthropic:
-    case GenericNetworkManager::PluginNetworkType::LastElement:
         return false;
     }
     return false;
 }
+
+#include "moc_genericnetworkserverinfo.cpp"
