@@ -4,6 +4,8 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "genericnetworkmodelavailableinfo.h"
+#include <QJsonObject>
+
 using namespace Qt::Literals::StringLiterals;
 GenericNetworkModelAvailableInfo::GenericNetworkModelAvailableInfo() = default;
 
@@ -34,6 +36,9 @@ void GenericNetworkModelAvailableInfo::parseCapabilities(const QJsonObject &obj)
     if (obj["vision"_L1].toBool(false)) {
         mCapabilities |= Capability::Vision;
     }
+    if (obj["function_calling"_L1].toBool(false)) {
+        mCapabilities |= Capability::Tools;
+    }
     // TODO add more
     // {"audio":false,"classification":false,"completion_chat":false,"completion_fim":false,"fine_tuning":false,"function_calling":false,"moderation":false,"ocr":false,"vision":false}
 }
@@ -109,7 +114,7 @@ GenericNetworkModelAvailableInfo::Capabilities GenericNetworkModelAvailableInfo:
     return mCapabilities;
 }
 
-void GenericNetworkModelAvailableInfo::setCapabilities(const Capabilities &newCapabilities)
+void GenericNetworkModelAvailableInfo::setCapabilities(Capabilities newCapabilities)
 {
     mCapabilities = newCapabilities;
 }
@@ -124,3 +129,5 @@ QDebug operator<<(QDebug d, const GenericNetworkModelAvailableInfo &t)
     d.space() << "ownedBy:" << t.ownedBy();
     return d;
 }
+
+#include "moc_genericnetworkmodelavailableinfo.cpp"
