@@ -5,21 +5,24 @@
 */
 #pragma once
 #include "textautogenerategenericnetwork_export.h"
-#include <QDebug>
-#include <QJsonObject>
+#include <QMetaType>
 #include <QString>
 
+class QDebug;
+class QJsonObject;
 class TEXTAUTOGENERATEGENERICNETWORK_EXPORT GenericNetworkModelAvailableInfo
 {
+    Q_GADGET
 public:
     enum Capability {
         None = 0,
         Vision = 1,
         Audio = 4,
         Ocr = 8,
+        Tools = 16,
     };
-    Q_FLAGS(Capability Capabilities)
     Q_DECLARE_FLAGS(Capabilities, Capability)
+    Q_FLAG(Capabilities)
 
     GenericNetworkModelAvailableInfo();
     ~GenericNetworkModelAvailableInfo();
@@ -45,7 +48,7 @@ public:
     void setOwnedBy(const QString &newOwnedBy);
 
     [[nodiscard]] Capabilities capabilities() const;
-    void setCapabilities(const Capabilities &newCapabilities);
+    void setCapabilities(Capabilities newCapabilities);
 
 private:
     TEXTAUTOGENERATEGENERICNETWORK_NO_EXPORT void parseCapabilities(const QJsonObject &obj);
