@@ -6,8 +6,7 @@
 
 #pragma once
 
-#include "widgets/view/textautogeneratelistviewbasedelegate.h"
-#include <QObject>
+#include "widgets/view/delegate/textautogeneratelistviewbasedelegate.h"
 
 class OllamaModelAvailableInfosDelegate : public TextAutoGenerateText::TextAutoGenerateListViewBaseDelegate
 {
