@@ -22,7 +22,7 @@ OllamaModelInstalledInfoWidget::OllamaModelInstalledInfoWidget(QWidget *parent)
     , mMainLayout(new QVBoxLayout(this))
     , mNetworkUrlButton(new OllamaNetworkUrlButton(this))
 {
-    mMainLayout->setObjectName(u"mainLayout"_s);
+    mMainLayout->setObjectName(u"mMainLayout"_s);
 
     mNetworkUrlButton->setObjectName(u"mNetworkUrlButton");
     mMainLayout->addWidget(mNetworkUrlButton, 0, Qt::AlignTop);
@@ -74,7 +74,7 @@ void OllamaModelInstalledInfoWidget::changeFont(QLabel *label)
 
 void OllamaModelInstalledInfoWidget::setOllamaModelInstalledInfo(const OllamaModelInstalledInfo &info)
 {
-    mNetworkUrlButton->setModelUrl(info.modelUrl());
+    mNetworkUrlButton->setUrl(info.modelUrl());
     mFamilyNameLabel->setText(info.family());
     mParameterSizeLabel->setText(info.parameterSize());
     mQuantizationLevelLabel->setText(info.quantizationLevel());
@@ -121,7 +121,7 @@ void OllamaModelInstalledInfoWidget::setOllamaModelInstalledInfo(const OllamaMod
         auto featuresGroupBox = new QGroupBox(i18n("Features Supported"), mInfoWidget);
         infoLayout->addWidget(featuresGroupBox);
         auto vboxfeaturesLayout = new TextAutoGenerateText::TextAutoGenerateFlowLayout(featuresGroupBox);
-        for (const QString &name : categoriesName) {
+        for (const QString &name : std::as_const(categoriesName)) {
             vboxfeaturesLayout->addWidget(new QLabel(name, mInfoWidget));
         }
     }
