@@ -14,25 +14,25 @@ OllamaNetworkUrlButton::OllamaNetworkUrlButton(QWidget *parent)
     : QToolButton(parent)
 {
     setIcon(QIcon::fromTheme(u"applications-network-symbolic"_s));
-    setToolTip(i18nc("@info:tooltip", "Open Model Information Url"));
     setAutoRaise(true);
     connect(this, &QToolButton::clicked, this, [this]() {
-        if (!mModelUrl.isEmpty()) {
-            QDesktopServices::openUrl(QUrl(mModelUrl));
+        if (!mUrl.isEmpty()) {
+            QDesktopServices::openUrl(QUrl(mUrl));
         }
     });
 }
 
 OllamaNetworkUrlButton::~OllamaNetworkUrlButton() = default;
 
-QString OllamaNetworkUrlButton::modelUrl() const
+QString OllamaNetworkUrlButton::url() const
 {
-    return mModelUrl;
+    return mUrl;
 }
 
-void OllamaNetworkUrlButton::setModelUrl(const QString &newModelUrl)
+void OllamaNetworkUrlButton::setUrl(const QString &newModelUrl)
 {
-    mModelUrl = newModelUrl;
+    mUrl = newModelUrl;
+    setToolTip(i18nc("@info:tooltip", "Open Url \"%1\"", mUrl));
 }
 
 #include "moc_ollamanetworkurlbutton.cpp"
