@@ -11,6 +11,7 @@ class OllamaComboBoxWidget;
 class OllamaManager;
 class QDoubleSpinBox;
 class QSpinBox;
+class OllamaConfigureCustomizeWidget;
 namespace TextAutoGenerateText
 {
 class TextAutoGenerateNotWorkingMessageWidget;
@@ -30,8 +31,8 @@ Q_SIGNALS:
     void enableOkButton(bool status);
 
 private:
-    void fillModels();
-    void slotStartOllama();
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void fillModels();
+    TEXTAUTOGENERATEOLLAMA_NO_EXPORT void slotStartOllama();
     QLineEdit *const mName;
     QLineEdit *const mServerUrl;
     OllamaComboBoxWidget *const mModelComboBoxWidget;
@@ -39,4 +40,5 @@ private:
     QDoubleSpinBox *const mTemperature;
     QSpinBox *const mSeed;
     OllamaManager *const mManager;
+    OllamaConfigureCustomizeWidget *const mOllamaConfigureCustomizeWidget;
 };
