@@ -12,6 +12,7 @@
 #include "ollamamanager.h"
 #include "ollamareply.h"
 #include "ollamasettings.h"
+#include "ollamastartprocessjob.h"
 #include <KLocalizedString>
 
 using namespace Qt::Literals::StringLiterals;
@@ -44,6 +45,9 @@ OllamaPlugin::OllamaPlugin(TextAutoGenerateText::TextAutoGenerateManager *manage
             Q_EMIT callTools(replyResponse.info);
         }
     });
+    connect(this->manager(), &TextAutoGenerateText::TextAutoGenerateManager::startOllamaRequested, this, [this]() {
+        slotOllamaRequested();
+    });
 }
 
 OllamaPlugin::~OllamaPlugin()
@@ -51,6 +55,18 @@ OllamaPlugin::~OllamaPlugin()
     delete mOllamaSettings;
 }
 
+void OllamaPlugin::slotOllamaRequested()
+{
+    auto job = new OllamaStartProcessJob(mOllamaManager, this);
+    connect(job, &OllamaStartProcessJob::ollamaStarted, this, [this]() {
+        Q_EMIT this->manager()->ollamaProcessOk(true);
+    });
+    connect(job, &OllamaStartProcessJob::ollamaFailed, this, [this](const QString &errorStr) {
+        Q_EMIT this->manager()->ollamaFailed();
+    });
+    job->start();
+}
+
 void OllamaPlugin::load(const KConfigGroup &config)
 {
     mOllamaSettings->setDisplayName(config.readEntry(u"Name"_s));
@@ -62,6 +78,11 @@ void OllamaPlugin::load(const KConfigGroup &config)
         mOllamaSettings->setTemperature(config.readEntry(u"Temperature"_s, 0.8));
     }
     mOllamaSettings->setCurrentModel(config.readEntry(u"CurrentModel"_s));
+
+    mOllamaSettings->setOverrideGfxVersion(config.readEntry(u"OverrideGfxVersion"_s));
+    mOllamaSettings->setVulkanSupport(config.readEntry(u"VulkanSupport"_s));
+    mOllamaSettings->setRocrVisibleDevice(config.readEntry(u"RocrVisibleDevice"_s));
+    mOllamaSettings->setCudaVisibleDevice(config.readEntry(u"CudaVisibleDevice"_s));
 }
 
 void OllamaPlugin::save(KConfigGroup &config)
@@ -71,6 +92,11 @@ void OllamaPlugin::save(KConfigGroup &config)
     config.writeEntry(u"ServerUrl"_s, mOllamaSettings->serverUrl());
     config.writeEntry(u"Temperature"_s, mOllamaSettings->temperature());
     config.writeEntry(u"CurrentModel"_s, mOllamaSettings->currentModel());
+
+    config.writeEntry(u"OverrideGfxVersion"_s, mOllamaSettings->overrideGfxVersion());
+    config.writeEntry(u"VulkanSupport"_s, mOllamaSettings->vulkanSupport());
+    config.writeEntry(u"RocrVisibleDevice"_s, mOllamaSettings->rocrVisibleDevice());
+    config.writeEntry(u"CudaVisibleDevice"_s, mOllamaSettings->cudaVisibleDevice());
 }
 
 TextAutoGenerateText::TextAutoGenerateTextPlugin::EngineType OllamaPlugin::engineType() const
@@ -132,7 +158,7 @@ void OllamaPlugin::sendToAssistant(const SendToAssistantInfo &info)
     mConnections.insert(
         reply,
         QPair<QByteArray, QMetaObject::Connection>(messageUuid, connect(reply, &OllamaReply::contentAdded, this, [reply, messageUuid, chatId, this]() {
-                                                       manager()->replaceContent(chatId, messageUuid, reply->readResponse());
+                                                       manager()->replaceContent(chatId, messageUuid, reply->readResponse(), {}); // TODO
                                                    })));
     mConnections.insert(
         reply,
@@ -190,4 +216,14 @@ bool OllamaPlugin::hasToolsSupport() const
     return mOllamaManager->hasToolsSupport(currentModel());
 }
 
+bool OllamaPlugin::hasOcrSupport() const
+{
+    return mOllamaManager->hasOcrSupport(currentModel());
+}
+
+bool OllamaPlugin::hasAudioSupport() const
+{
+    return mOllamaManager->hasAudioSupport(currentModel());
+}
+
 #include "moc_ollamaplugin.cpp"
