@@ -37,12 +37,15 @@ public:
 
     [[nodiscard]] bool hasVisionSupport() const override;
     [[nodiscard]] bool hasToolsSupport() const override;
+    [[nodiscard]] bool hasOcrSupport() const override;
+    [[nodiscard]] bool hasAudioSupport() const override;
 
 protected:
     void sendToAssistant(const SendToAssistantInfo &info) override;
     void askToAssistant(const QString &msg) override;
 
 private:
+    void slotOllamaRequested();
     OllamaSettings *const mOllamaSettings;
     OllamaManager *const mOllamaManager;
 };
