@@ -5,13 +5,15 @@
 */
 
 #include "textautogeneratenotworkingwidget.h"
-#include "core/textautogeneratetextutils.h"
+
 #include "textautogeneratenotworkingmessagewidget.h"
 #include "textautogeneratetextwidget_debug.h"
 #include <KLocalizedString>
 #include <QProcess>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <TextAddonsWidgets/ExecutableUtils>
+#include <TextAutoGenerateText/TextAutoGenerateManager>
 
 using namespace TextAutoGenerateText;
 using namespace Qt::Literals::StringLiterals;
@@ -33,6 +35,16 @@ TextAutoGenerateNotWorkingWidget::TextAutoGenerateNotWorkingWidget(TextAutoGener
     connect(configureButton, &QPushButton::clicked, this, &TextAutoGenerateNotWorkingWidget::configureInstances);
     mainLayout->addWidget(configureButton, 0, Qt::AlignVCenter);
     mainLayout->addStretch(1);
+    // TODO configure from activate instance
+    connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::ollamaProcessOk, this, [this](bool state) {
+        if (state) {
+            clearMessage();
+            Q_EMIT ollamaStarted();
+        }
+    });
+    connect(mManager, &TextAutoGenerateText::TextAutoGenerateManager::ollamaFailed, this, [this]() {
+        qCWarning(TEXTAUTOGENERATETEXT_WIDGET_LOG) << "Ollama doesn't exist";
+    });
 }
 
 TextAutoGenerateNotWorkingWidget::~TextAutoGenerateNotWorkingWidget() = default;
@@ -51,18 +63,7 @@ void TextAutoGenerateNotWorkingWidget::clearMessage()
 
 void TextAutoGenerateNotWorkingWidget::slotStartOllama()
 {
-    const QString ollamaPath = TextAutoGenerateText::TextAutoGenerateTextUtils::findExecutable(u"ollama"_s);
-    if (ollamaPath.isEmpty()) {
-        qCWarning(TEXTAUTOGENERATETEXT_WIDGET_LOG) << "Ollama doesn't exist";
-        return;
-    }
-    const bool status = QProcess::startDetached(ollamaPath, {u"start"_s});
-    if (!status) {
-        qCWarning(TEXTAUTOGENERATETEXT_WIDGET_LOG) << "Impossible to start ollama";
-    } else {
-        clearMessage();
-        Q_EMIT ollamaStarted();
-    }
+    Q_EMIT startOllamaRequested();
 }
 
 #include "moc_textautogeneratenotworkingwidget.cpp"
