@@ -5,7 +5,6 @@
 */
 
 #include "textautogeneratemenuwidget.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "textautogeneratemenuconfiguredialog.h"
 #include "textautogeneratemenutextmanager.h"
@@ -14,6 +13,7 @@ using namespace Qt::Literals::StringLiterals;
 
 #include <KLocalizedString>
 #include <QMenu>
+using namespace Qt::Literals::StringLiterals;
 using namespace TextAutoGenerateText;
 TextAutoGenerateMenuWidget::TextAutoGenerateMenuWidget(QObject *parent)
     : TextAutoGenerateMenuWidget(new TextAutoGenerateMenuTextManager(parent), parent)
@@ -55,7 +55,10 @@ void TextAutoGenerateMenuWidget::initializeMenu()
                 auto dlg = new TextAutoGenerateText::TextAutoGenerateQuickAskDialog(mManager, mParentWidget);
                 dlg->setAttribute(Qt::WA_DeleteOnClose);
                 dlg->show();
-                dlg->ask(u"%1 %2"_s.arg(requestText, mSelectedText));
+                TextAutoGenerateText::TextAutoGenerateManager::AskMessageInfo info;
+                info.message = u"%1 %2"_s.arg(requestText, mSelectedText);
+
+                dlg->ask(info);
             });
             mTextMenu->addAction(action);
         }
