@@ -4,9 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "textautogeneratequickaskdialog.h"
-using namespace Qt::Literals::StringLiterals;
 
-#include "core/textautogeneratemanager.h"
 #include "textautogeneratequickaskwidget.h"
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -21,6 +19,7 @@ namespace
 const char myQuickAskDialogGroupName[] = "QuickAskDialog";
 }
 
+using namespace Qt::Literals::StringLiterals;
 using namespace TextAutoGenerateText;
 TextAutoGenerateQuickAskDialog::TextAutoGenerateQuickAskDialog(TextAutoGenerateText::TextAutoGenerateManager *manager, QWidget *parent)
     : QDialog(parent)
@@ -47,9 +46,9 @@ TextAutoGenerateQuickAskDialog::~TextAutoGenerateQuickAskDialog()
     writeConfig();
 }
 
-void TextAutoGenerateQuickAskDialog::ask(const QString &str)
+void TextAutoGenerateQuickAskDialog::ask(const TextAutoGenerateText::TextAutoGenerateManager::AskMessageInfo &info)
 {
-    mManager->ask(str);
+    mManager->ask(info);
 }
 
 void TextAutoGenerateQuickAskDialog::readConfig()
