@@ -8,6 +8,7 @@
 #include <QWidget>
 #include <TextAutoGenerateText/TextAutoGenerateTextPlugin>
 class QLabel;
+class QToolButton;
 namespace TextAutoGenerateText
 {
 class TextAutoGenerateManager;
@@ -23,12 +24,15 @@ public:
 
     void setModelList(const QList<TextAutoGenerateText::TextAutoGenerateTextPlugin::ModelInfoNameAndIdentifier> &lst);
     [[nodiscard]] QString currentModel() const;
+    void slotCloseQuickSearchRequested();
 Q_SIGNALS:
     void configureRequested();
+    void searchText(bool checked);
 
 private:
     QLabel *const mModelInstanceLabel;
     TextAutoGenerateTextModelComboBox *const mModelComboBox;
     TextAutoGenerateText::TextAutoGenerateManager *const mManager;
+    QToolButton *const mSearchButton;
 };
 }
