@@ -12,7 +12,6 @@
 #include "core/textautogeneratetextinstancesmanager.h"
 #include "core/textautogeneratetextplugin.h"
 #include "textautogeneratequickaskviewwidget.h"
-#include "textautogeneratetextwidget_debug.h"
 #include "widgets/common/textautogeneratenotinstancefoundwidget.h"
 #include "widgets/common/textautogeneratenotworkingwidget.h"
 #include <QStackedWidget>
@@ -52,6 +51,10 @@ TextAutoGenerateQuickAskWidget::TextAutoGenerateQuickAskWidget(TextAutoGenerateT
     connect(mTextAutoGenerateNotWorkingWidget, &TextAutoGenerateNotWorkingWidget::ollamaStarted, this, [this]() {
         mStackedWidget->setCurrentWidget(mTextAutoGenerateQuickAskViewWidget);
     });
+    connect(mTextAutoGenerateNotWorkingWidget, &TextAutoGenerateNotWorkingWidget::startOllamaRequested, this, [this]() {
+        Q_EMIT mManager->startOllamaRequested();
+    });
+
     connect(mTextAutoGenerateNotWorkingWidget,
             &TextAutoGenerateNotWorkingWidget::configureInstances,
             this,
@@ -60,7 +63,7 @@ TextAutoGenerateQuickAskWidget::TextAutoGenerateQuickAskWidget(TextAutoGenerateT
     connect(mTextAutoGenerateQuickAskViewWidget,
             &TextAutoGenerateQuickAskViewWidget::editingFinished,
             this,
-            &TextAutoGenerateQuickAskWidget::slotEditingFinished);
+            &TextAutoGenerateQuickAskWidget::slotEditingFinished2);
 
     connect(mTextAutoGenerateQuickAskViewWidget,
             &TextAutoGenerateQuickAskViewWidget::cancelRequested,
@@ -82,9 +85,12 @@ TextAutoGenerateQuickAskWidget::TextAutoGenerateQuickAskWidget(TextAutoGenerateT
 
     if (mManager) {
         mManager->setSaveInDatabase(false);
-        connect(mManager, &TextAutoGenerateManager::askMessageRequested, this, [this](const QString &str) {
-            slotAskMessageRequester(str);
-        });
+        connect(mManager,
+                &TextAutoGenerateManager::askMessageRequested,
+                this,
+                [this](const TextAutoGenerateText::TextAutoGenerateManager::AskMessageInfo &info) {
+                    slotAskMessageRequester(info);
+                });
     }
     loadEngine();
 }
@@ -103,12 +109,12 @@ void TextAutoGenerateQuickAskWidget::slotEditMessage(const QModelIndex &index)
     mTextAutoGenerateQuickAskViewWidget->editMessage(uuid, messageStr);
 }
 
-void TextAutoGenerateQuickAskWidget::slotAskMessageRequester(const QString &str)
+void TextAutoGenerateQuickAskWidget::slotAskMessageRequester(const TextAutoGenerateText::TextAutoGenerateManager::AskMessageInfo &info)
 {
     if (!mPluginWasInitialized) {
-        mAskMessageList.append(str);
+        mAskMessageList.append(info);
     } else {
-        slotEditingFinished(str, {});
+        slotEditingFinished(info, {});
     }
 }
 
@@ -138,7 +144,12 @@ void TextAutoGenerateQuickAskWidget::slotRefreshAnswer(const QByteArray &chatId,
 {
     const QByteArray uuid = index.data(TextAutoGenerateMessagesModel::UuidRole).toByteArray();
     const QString messageStr = index.data(TextAutoGenerateMessagesModel::OriginalMessageRole).toString();
-    mManager->textAutoGeneratePlugin()->editMessage(chatId, uuid, messageStr, {}); // TODO
+    const TextAutoGenerateText::TextAutoGenerateTextPlugin::EditSendInfo info = {.message = messageStr,
+                                                                                 .messageUuid = uuid,
+                                                                                 .chatId = chatId,
+                                                                                 .tools = {},
+                                                                                 .attachmentInfoList = {}};
+    mManager->textAutoGeneratePlugin()->editMessage(info);
 }
 
 void TextAutoGenerateQuickAskWidget::loadEngine()
@@ -165,19 +176,58 @@ void TextAutoGenerateQuickAskWidget::slotAutogenerateFailed(const QString &str)
 void TextAutoGenerateQuickAskWidget::slotInitializeDone()
 {
     mPluginWasInitialized = true;
-    for (const auto &str : std::as_const(mAskMessageList)) {
-        slotEditingFinished(str, {});
+    for (const auto &info : std::as_const(mAskMessageList)) {
+        slotEditingFinished(info, {});
     }
     mAskMessageList.clear();
 }
 
-void TextAutoGenerateQuickAskWidget::slotEditingFinished(const QString &str, const QByteArray &messageUuid)
+void TextAutoGenerateQuickAskWidget::slotEditingFinished2(
+    const QString &str,
+    const QByteArray &messageUuid,
+    const QList<QByteArray> &lstTools,
+    const QList<TextAutoGenerateText::TextAutoGenerateAttachmentUtils::AttachmentElementInfo> &attachmentInfoList)
 {
     mManager->checkCurrentChat();
+
     if (messageUuid.isEmpty()) {
-        mManager->textAutoGeneratePlugin()->sendMessage(mManager->currentChatId(), str, {}); // TODO
+        const TextAutoGenerateText::TextAutoGenerateTextPlugin::EditSendInfo sendInfo = {.message = str,
+                                                                                         .messageUuid = {},
+                                                                                         .chatId = mManager->currentChatId(),
+                                                                                         .tools = lstTools,
+                                                                                         .attachmentInfoList = attachmentInfoList};
+        mManager->textAutoGeneratePlugin()->sendMessage(sendInfo);
     } else {
-        mManager->textAutoGeneratePlugin()->editMessage(mManager->currentChatId(), messageUuid, str, {}); // TODO
+        const TextAutoGenerateText::TextAutoGenerateTextPlugin::EditSendInfo sendInfo = {.message = str,
+                                                                                         .messageUuid = messageUuid,
+                                                                                         .chatId = mManager->currentChatId(),
+                                                                                         .tools = lstTools,
+                                                                                         .attachmentInfoList = attachmentInfoList};
+        mManager->textAutoGeneratePlugin()->editMessage(sendInfo);
+    }
+}
+
+void TextAutoGenerateQuickAskWidget::slotEditingFinished(const TextAutoGenerateText::TextAutoGenerateManager::AskMessageInfo &info,
+                                                         const QByteArray &messageUuid)
+{
+    mManager->checkCurrentChat();
+
+    if (messageUuid.isEmpty()) {
+        const TextAutoGenerateText::TextAutoGenerateTextPlugin::EditSendInfo sendInfo = {
+            .message = info.message,
+            .messageUuid = {},
+            .chatId = mManager->currentChatId(),
+            .tools = info.tools,
+            .attachmentInfoList = TextAutoGenerateAttachmentUtils::createAttachmentElementInfoFromFileList(info.attachments)};
+        mManager->textAutoGeneratePlugin()->sendMessage(sendInfo);
+    } else {
+        const TextAutoGenerateText::TextAutoGenerateTextPlugin::EditSendInfo sendInfo = {
+            .message = info.message,
+            .messageUuid = messageUuid,
+            .chatId = mManager->currentChatId(),
+            .tools = info.tools,
+            .attachmentInfoList = TextAutoGenerateAttachmentUtils::createAttachmentElementInfoFromFileList(info.attachments)};
+        mManager->textAutoGeneratePlugin()->editMessage(sendInfo);
     }
     // mTextAutoGenerateResultWidget->editingFinished(uuid);
 }
