@@ -38,6 +38,7 @@ TextAutoGenerateHeaderWidget::TextAutoGenerateHeaderWidget(TextAutoGenerateText:
     mSearch->setObjectName("mSearch"_L1);
     mSearch->setToolTip(i18nc("@info:tooltip", "Search…"));
     mSearch->setAutoRaise(true);
+    mSearch->setCheckable(true);
     mSearch->setIcon(QIcon::fromTheme(u"search"_s));
     mainLayout->addWidget(mSearch);
     connect(mSearch, &QToolButton::clicked, this, &TextAutoGenerateHeaderWidget::searchText);
@@ -98,4 +99,9 @@ QString TextAutoGenerateHeaderWidget::currentModel() const
     return mModelComboBox->currentModel();
 }
 
+void TextAutoGenerateHeaderWidget::slotCloseQuickSearchRequested()
+{
+    mSearch->setChecked(false);
+}
+
 #include "moc_textautogenerateheaderwidget.cpp"
