@@ -23,10 +23,11 @@ public:
 
     void setModelList(const QList<TextAutoGenerateText::TextAutoGenerateTextPlugin::ModelInfoNameAndIdentifier> &lst);
     [[nodiscard]] QString currentModel() const;
+    void slotCloseQuickSearchRequested();
 Q_SIGNALS:
     void addNewChat();
     void changeFavoriteRequested(bool f);
-    void searchText();
+    void searchText(bool checked);
 
 private:
     TEXTAUTOGENERATETEXT_NO_EXPORT void slotCurrentChatIdChanged();
