@@ -4,33 +4,41 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "textautogeneratelistviewdelegate.h"
+#include "config-textautogeneratetext.h"
+#include "textautogeneratetextglobalconfig.h"
 
 #include "core/models/textautogeneratemessagesmodel.h"
 #include "textautogeneratetextwidget_debug.h"
-#include "widgets/view/textautogeneratecolorsandmessageviewstyle.h"
 #include "widgets/view/textautogeneratelistviewtextselection.h"
+#include <KIconLoader>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <QAbstractTextDocumentLayout>
+#include <QClipboard>
 #include <QDesktopServices>
 #include <QDrag>
 #include <QListView>
 #include <QMimeData>
 #include <QPainter>
 #include <QToolTip>
+#include <TextUtils/TextUtilsBlockCodeManager>
+#include <TextUtils/TextUtilsColorsAndMessageViewStyle>
+#include <TextUtils/TextUtilsSyntaxHighlighter>
 
 using namespace Qt::Literals::StringLiterals;
 using namespace TextAutoGenerateText;
-TextAutoGenerateListViewDelegate::TextAutoGenerateListViewDelegate(QListView *view)
-    : TextAutoGenerateListViewBaseDelegate{view}
+TextAutoGenerateListViewDelegate::TextAutoGenerateListViewDelegate(TextAutoGenerateText::TextAutoGenerateManager *manager, QListView *view)
+    : TextAutoGenerateListViewMessageBaseDelegate{manager, view}
     , mEditedIcon(QIcon::fromTheme(u"document-edit"_s))
     , mCopyIcon(QIcon::fromTheme(u"edit-copy"_s))
     , mCancelIcon(QIcon::fromTheme(u"dialog-cancel"_s))
     , mRefreshIcon(QIcon::fromTheme(u"view-refresh"_s))
     , mInformationIcon(QIcon::fromTheme(u"info"_s))
     , mRemoveIcon(QIcon::fromTheme(u"edit-delete"_s))
+    , mTextToSpeechIcon(QIcon::fromTheme(u"player-volume"_s))
 {
-    connect(&TextAutoGenerateColorsAndMessageViewStyle::self(),
-            &TextAutoGenerateColorsAndMessageViewStyle::needToUpdateColors,
+    connect(&TextUtils::TextUtilsColorsAndMessageViewStyle::self(),
+            &TextUtils::TextUtilsColorsAndMessageViewStyle::needToUpdateColors,
             this,
             &TextAutoGenerateListViewDelegate::slotUpdateColors);
     slotUpdateColors();
@@ -40,9 +48,11 @@ TextAutoGenerateListViewDelegate::~TextAutoGenerateListViewDelegate() = default;
 
 void TextAutoGenerateListViewDelegate::slotUpdateColors()
 {
-    const KColorScheme scheme = TextAutoGenerateColorsAndMessageViewStyle::self().schemeView();
+    const KColorScheme scheme = TextUtils::TextUtilsColorsAndMessageViewStyle::self().schemeView();
     mEditingColorMode = scheme.foreground(KColorScheme::NegativeText).color();
-    Q_EMIT updateView();
+    // KIconLoader::global()->setCustomPalette(mListView->palette());
+    // KIconLoader::global()->resetPalette();
+    Q_EMIT updateColors();
 }
 
 void TextAutoGenerateListViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -78,6 +88,12 @@ void TextAutoGenerateListViewDelegate::paint(QPainter *painter, const QStyleOpti
                 QBrush(isUser ? option.palette.color(QPalette::Inactive, QPalette::Midlight) : option.palette.color(QPalette::Active, QPalette::Mid)));
         }
         painter->setRenderHint(QPainter::Antialiasing);
+        if (message->textToSpeechInProgress()) {
+            QPen pen;
+            pen.setWidth(3);
+            pen.setColor(Qt::blue);
+            painter->setPen(pen);
+        }
         painter->drawRoundedRect(
             QRect(layout.decoRect.topLeft(), QSize(layout.decoRect.width(), layout.decoRect.height() - TextAutoGenerateDelegateUtils::spacingText() - 5)),
             TextAutoGenerateDelegateUtils::roundRectValue(),
@@ -86,9 +102,13 @@ void TextAutoGenerateListViewDelegate::paint(QPainter *painter, const QStyleOpti
         draw(painter, layout, index, option);
     }
 
-    if (auto att = message->messageAttachment(); att) {
-        const TextAutoGenerateAttachmentDelegateHelperBase *helper = attachmentsHelper(att);
-        helper->draw(painter, {}, index, option);
+    if (auto att = message->messageAttachments(); att) {
+        int i = 0;
+        for (const auto &attachment : att->messageAttachments()) {
+            const TextAutoGenerateAttachmentDelegateHelperBase *helper = attachmentsHelper(attachment);
+            helper->draw(attachment, painter, layout.attachmentsRectList.isEmpty() ? QRect{} : layout.attachmentsRectList.at(i), index, option);
+            i++;
+        }
     }
 
     drawDateAndIcons(painter, index, option, layout);
@@ -191,10 +211,15 @@ void TextAutoGenerateListViewDelegate::drawDateAndIcons(QPainter *painter,
         int iconSizeAreaWidth = 0;
         const bool inProgress = index.data(TextAutoGenerateMessagesModel::FinishedRole).toBool();
         if (isMouseOver) {
+            int offset = 0;
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+            offset = TextAutoGenerateText::TextAutogenerateTextGlobalConfig::self()->enableTextToSpeech() ? 1 : 0;
+#endif
+
             if (!inProgress) {
-                iconSizeAreaWidth = 3 * (buttonIconSize(option) + TextAutoGenerateDelegateUtils::iconSpacing());
+                iconSizeAreaWidth = (3 + offset) * (buttonIconSize(option) + TextAutoGenerateDelegateUtils::iconSpacing());
             } else {
-                iconSizeAreaWidth = 2 * (buttonIconSize(option) + TextAutoGenerateDelegateUtils::iconSpacing());
+                iconSizeAreaWidth = (2 + offset) * (buttonIconSize(option) + TextAutoGenerateDelegateUtils::iconSpacing());
             }
         }
         painter->drawLine(dateTextRect.right() + margin, lineY, layout.dateAreaRect.right() - iconSizeAreaWidth, lineY);
@@ -212,6 +237,11 @@ void TextAutoGenerateListViewDelegate::drawDateAndIcons(QPainter *painter,
         if (layout.removeIconRect.isValid()) {
             mRemoveIcon.paint(painter, layout.removeIconRect);
         }
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+        if (TextAutoGenerateText::TextAutogenerateTextGlobalConfig::self()->enableTextToSpeech() && layout.textToSpeechIconRect.isValid()) {
+            mTextToSpeechIcon.paint(painter, layout.textToSpeechIconRect);
+        }
+#endif
         if (layout.cancelIconRect.isValid()) {
             mCancelIcon.paint(painter, layout.cancelIconRect);
         }
@@ -269,11 +299,20 @@ TextAutoGenerateListViewDelegate::MessageLayout TextAutoGenerateListViewDelegate
     } else {
         usableRect.setBottom(usableRect.bottom() + iconSize);
     }
-
+    const TextAutoGenerateMessage *message = index.data(TextAutoGenerateMessagesModel::MessagePointer).value<TextAutoGenerateMessage *>();
     int maxWidth = qMax(30, option.rect.width() - indent - TextAutoGenerateDelegateUtils::rightIndent());
     const QSize textSize = documentSizeHint(index, maxWidth, option, &layout.baseLine);
+    int attachmentWidth = textSize.width();
+    if (message->messageAttachments() && !message->messageAttachments()->isEmpty()) {
+        const auto attachments = message->messageAttachments()->messageAttachments();
+        for (const TextAutoGenerateAttachment &msgAttach : attachments) {
+            const TextAutoGenerateAttachmentDelegateHelperBase *helper = attachmentsHelper(msgAttach);
+            attachmentWidth = qMax(attachmentWidth, helper ? helper->sizeHint(msgAttach, index, maxWidth, option).width() : 0);
+        }
+    }
+
     if (isUser) {
-        maxWidth = qMax(30, textSize.width() + TextAutoGenerateDelegateUtils::rightIndent() + TextAutoGenerateDelegateUtils::marginText());
+        maxWidth = qMax(30, attachmentWidth + TextAutoGenerateDelegateUtils::rightIndent() + TextAutoGenerateDelegateUtils::marginText());
         layout.textRect = QRect(option.rect.width() - maxWidth,
                                 usableRect.top() + TextAutoGenerateDelegateUtils::spacingText() * 2,
                                 maxWidth - TextAutoGenerateDelegateUtils::marginText() * 2,
@@ -295,13 +334,40 @@ TextAutoGenerateListViewDelegate::MessageLayout TextAutoGenerateListViewDelegate
                                 maxWidth,
                                 layout.textRect.height() + TextAutoGenerateDelegateUtils::spacingText() * 3);
     }
+
+    if (message->messageAttachments() && !message->messageAttachments()->isEmpty()) {
+        const auto attachments = message->messageAttachments()->messageAttachments();
+        QSize attachmentsSize;
+        const int offsetSpacing = TextAutoGenerateDelegateUtils::spacingText();
+        int topAttachment = layout.textRect.y() + offsetSpacing;
+        for (const TextAutoGenerateAttachment &msgAttach : attachments) {
+            const TextAutoGenerateAttachmentDelegateHelperBase *helper = attachmentsHelper(msgAttach);
+            if (attachmentsSize.isEmpty()) {
+                attachmentsSize = helper ? helper->sizeHint(msgAttach, index, maxWidth, option) : QSize(0, 0);
+                layout.attachmentsRectList.append(QRect(layout.textRect.x() - TextAutoGenerateDelegateUtils::rightIndent(),
+                                                        topAttachment,
+                                                        attachmentsSize.width(),
+                                                        attachmentsSize.height()));
+                topAttachment += attachmentsSize.height();
+            } else {
+                topAttachment += offsetSpacing;
+                const QSize attSize = helper ? helper->sizeHint(msgAttach, index, maxWidth, option) : QSize(0, 0);
+                attachmentsSize = QSize(qMax(attachmentsSize.width(), attSize.width()), attSize.height() + attachmentsSize.height());
+                layout.attachmentsRectList.append(
+                    QRect(layout.textRect.x() - TextAutoGenerateDelegateUtils::rightIndent(), topAttachment, attSize.width(), attSize.height()));
+                topAttachment += attSize.height();
+            }
+        }
+        layout.decoRect.setHeight(layout.decoRect.height() + attachmentsSize.height() + attachments.count() * offsetSpacing);
+    }
+
     layout.dateAreaRect = QRect(layout.decoRect.x(),
-                                layout.textRect.y() + layout.textRect.height() + TextAutoGenerateDelegateUtils::spacingText(),
+                                layout.decoRect.y() + layout.decoRect.height() - TextAutoGenerateDelegateUtils::spacingText() / 2,
                                 layout.decoRect.width(),
                                 qMax(layout.dateSize.height(), iconSize)); // the whole row
 
     int positionIcon = layout.decoRect.right() - iconSize;
-    const int lineY = (layout.dateAreaRect.top() + layout.dateAreaRect.bottom() - iconSize) / 2;
+    const int lineY = layout.dateAreaRect.center().y() - (iconSize / 2);
     const bool waitingAnswer = index.data(TextAutoGenerateMessagesModel::WaitingAnswerRole).toBool();
     if (isUser && !waitingAnswer && !mShowArchive && !mInProgress) {
         layout.removeIconRect = QRect(positionIcon, lineY, iconSize, iconSize);
@@ -324,6 +390,12 @@ TextAutoGenerateListViewDelegate::MessageLayout TextAutoGenerateListViewDelegate
 
         layout.infoIconRect = QRect(layout.textRect.topRight().x(), layout.textRect.topRight().y(), iconSize, iconSize);
     }
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    if (TextAutoGenerateText::TextAutogenerateTextGlobalConfig::self()->enableTextToSpeech()) {
+        positionIcon -= iconSize + TextAutoGenerateDelegateUtils::iconSpacing();
+        layout.textToSpeechIconRect = QRect(positionIcon, lineY, iconSize, iconSize);
+    }
+#endif
 
     const QSize progressIndicatorSize = TextAutoGenerateDelegateUtils::progressIndicatorSize();
     layout.inProgressRect = QRect(layout.textRect.topRight().x() - progressIndicatorSize.width(),
@@ -343,6 +415,18 @@ bool TextAutoGenerateListViewDelegate::mouseEvent(QEvent *event, const QStyleOpt
         if (handleMouseEvent(mev, layout.decoRect, option, index)) {
             return true;
         }
+        const TextAutoGenerateMessage *message = index.data(TextAutoGenerateMessagesModel::MessagePointer).value<TextAutoGenerateMessage *>();
+        if (message->messageAttachments()) {
+            const auto attachments = message->messageAttachments()->messageAttachments();
+            int i = 0;
+            for (const TextAutoGenerateAttachment &att : attachments) {
+                TextAutoGenerateAttachmentDelegateHelperBase *helper = attachmentsHelper(att);
+                if (helper && helper->handleMouseEvent(att, mev, layout.attachmentsRectList.at(i), option, index)) {
+                    return true;
+                }
+                ++i;
+            }
+        }
     } else if (eventType == QEvent::MouseButtonPress || eventType == QEvent::MouseMove || eventType == QEvent::MouseButtonDblClick) {
         auto mev = static_cast<QMouseEvent *>(event);
         if (mev->buttons() & Qt::LeftButton) {
@@ -385,6 +469,11 @@ bool TextAutoGenerateListViewDelegate::helpEvent(QHelpEvent *helpEvent, QAbstrac
             QToolTip::showText(helpEvent->globalPos(), i18nc("@info:tooltip", "Remove"), view);
             return true;
         }
+        if (layout.textToSpeechIconRect.contains(helpEventPos)) {
+            const bool textToSpeechInProgress = index.data(TextAutoGenerateMessagesModel::TextToSpeechInProgressRole).toBool();
+            QToolTip::showText(helpEvent->globalPos(), textToSpeechInProgress ? i18nc("@info:tooltip", "Stop") : i18nc("@info:tooltip", "Speak"), view);
+            return true;
+        }
         if (layout.copyIconRect.contains(helpEventPos)) {
             QToolTip::showText(helpEvent->globalPos(), i18nc("@info:tooltip", "Copy"), view);
             return true;
@@ -463,7 +552,7 @@ bool TextAutoGenerateListViewDelegate::maybeStartDrag(QMouseEvent *mouseEvent, Q
 }
 bool TextAutoGenerateListViewDelegate::handleMouseEvent(QMouseEvent *mouseEvent,
                                                         QRect messageRect,
-                                                        [[maybe_unused]] const QStyleOptionViewItem &option,
+                                                        const QStyleOptionViewItem &option,
                                                         const QModelIndex &index)
 {
     if (!messageRect.contains(mouseEvent->pos())) {
@@ -471,7 +560,7 @@ bool TextAutoGenerateListViewDelegate::handleMouseEvent(QMouseEvent *mouseEvent,
     }
 
     const QPoint pos =
-        mouseEvent->pos() - messageRect.topLeft() + QPoint(-TextAutoGenerateDelegateUtils::spacingText() * 2, -TextAutoGenerateDelegateUtils::marginText());
+        mouseEvent->pos() - messageRect.topLeft() + QPoint(-TextAutoGenerateDelegateUtils::spacingText() * 2, -TextAutoGenerateDelegateUtils::spacingText());
 
     const QEvent::Type eventType = mouseEvent->type();
 
@@ -520,7 +609,18 @@ bool TextAutoGenerateListViewDelegate::handleMouseEvent(QMouseEvent *mouseEvent,
             if (const auto *doc = documentForIndex(index, messageRect.width())) {
                 const QString link = doc->documentLayout()->anchorAt(pos);
                 if (!link.isEmpty()) {
-                    QDesktopServices::openUrl(QUrl(link));
+                    if (link.startsWith(TextUtils::TextUtilsSyntaxHighlighter::copyHref())) {
+                        QString identifier = link;
+                        identifier.remove(TextUtils::TextUtilsSyntaxHighlighter::copyHref());
+                        // qDebug() << "identifier**************************** " << identifier;
+                        const QString blockCodeStr = TextUtils::TextUtilsBlockCodeManager::self()->blockCode(identifier);
+                        QClipboard *clipboard = QGuiApplication::clipboard();
+                        clipboard->setText(blockCodeStr, QClipboard::Clipboard);
+                        clipboard->setText(blockCodeStr, QClipboard::Selection);
+                        KMessageBox::information(mListView, i18n("Block Code copied."), i18nc("@title", "Copy Block Code"));
+                    } else {
+                        QDesktopServices::openUrl(QUrl(link));
+                    }
                     return true;
                 }
             }
@@ -543,6 +643,14 @@ bool TextAutoGenerateListViewDelegate::handleMouseEvent(QMouseEvent *mouseEvent,
         } else if (layout.refreshIconRect.contains(mouseEvent->pos())) {
             Q_EMIT refreshRequested(index);
             return true;
+        } else if (layout.textToSpeechIconRect.contains(mouseEvent->pos())) {
+            const bool textToSpeechInProgress = index.data(TextAutoGenerateMessagesModel::TextToSpeechInProgressRole).toBool();
+            if (textToSpeechInProgress) {
+                Q_EMIT stopTextToSpeechRequested(index);
+            } else {
+                Q_EMIT textToSpeechRequested(index);
+            }
+            return true;
         }
         // don't return true here, we need to send mouse release events to other helpers (ex: click on image)
         break;
@@ -571,7 +679,7 @@ void TextAutoGenerateListViewDelegate::needUpdateIndexBackground(const QPersiste
 {
     removeNeedUpdateIndexBackground(index);
     const IndexBackgroundColor back{.index = index, .color = color};
-    mIndexBackgroundColorList.append(std::move(back));
+    mIndexBackgroundColorList.append(back);
 }
 
 void TextAutoGenerateListViewDelegate::removeNeedUpdateIndexBackground(const QPersistentModelIndex &index)
