@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,22 +20,42 @@ class TEXTCUSTOMEDITOR_EXPORT TextGoToLineWidget : public QWidget
 {
     Q_OBJECT
 public:
+    /*!
+     */
     explicit TextGoToLineWidget(QWidget *parent = nullptr);
+    /*!
+     */
     ~TextGoToLineWidget() override;
 
+    /*!
+     */
     void goToLine();
 
+    /*!
+     */
     void setMaximumLineCount(int max);
 Q_SIGNALS:
+    /*!
+     */
     void moveToLine(int);
+    /*!
+     */
     void hideGotoLine();
 
 protected:
+    /*!
+     */
     bool event(QEvent *e) override;
+    /*!
+     */
     void showEvent(QShowEvent *e) override;
+    /*!
+     */
     bool eventFilter(QObject *obj, QEvent *event) override;
 
-public Q_SLOTS:
+public:
+    /*!
+     */
     void slotBlockCountChanged(int numberBlockCount);
 
 private:
