@@ -60,6 +60,7 @@ void TextToSpeechConfigInterface::setEngine(const QString &engineName)
     if (!mTextToSpeech || (mTextToSpeech->engine() != engineName)) {
         delete mTextToSpeech;
         mTextToSpeech = new QTextToSpeech(engineName, this);
+        connect(mTextToSpeech, &QTextToSpeech::stateChanged, this, &TextToSpeechConfigInterface::stateChanged);
     }
 }
 
@@ -85,6 +86,13 @@ void TextToSpeechConfigInterface::testEngine(const EngineSettings &engineSetting
     mTextToSpeech->say(i18n("Morning, this is the test for testing settings."));
 }
 
+void TextToSpeechConfigInterface::stop()
+{
+    if (mTextToSpeech->state() == QTextToSpeech::Speaking) {
+        mTextToSpeech->stop();
+    }
+}
+
 QDebug operator<<(QDebug d, const TextEditTextToSpeech::TextToSpeechConfigInterface::EngineSettings &t)
 {
     d << " Rate " << t.rate;
