@@ -36,6 +36,7 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     , mTestButton(new QPushButton(QIcon::fromTheme(u"player-volume"_s), i18n("Test"), this))
 {
     auto layout = new QFormLayout(this);
+    layout->setContentsMargins({});
     mVolume->setObjectName(u"volume"_s);
     mVolume->setRange(0, 100);
     connect(mVolume, &TextToSpeechSliderWidget::valueChanged, this, &TextToSpeechConfigWidget::valueChanged);
@@ -65,13 +66,21 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     connect(mVoice, &QComboBox::currentIndexChanged, this, &TextToSpeechConfigWidget::valueChanged);
 
     mTestButton->setObjectName(u"mTestButton"_s);
+    mTestButton->setCheckable(true);
+    mTestButton->setChecked(false);
     layout->addWidget(mTestButton);
     connect(mTestButton, &QPushButton::clicked, this, &TextToSpeechConfigWidget::slotTestTextToSpeech);
     QTimer::singleShot(0, this, &TextToSpeechConfigWidget::slotUpdateSettings);
+    connect(mTextToSpeechConfigInterface, &TextToSpeechConfigInterface::stateChanged, this, &TextToSpeechConfigWidget::slotTextChanged);
 }
 
 TextToSpeechConfigWidget::~TextToSpeechConfigWidget() = default;
 
+void TextToSpeechConfigWidget::slotTextChanged(QTextToSpeech::State state)
+{
+    mTestButton->setChecked(state == QTextToSpeech::Speaking);
+}
+
 void TextToSpeechConfigWidget::initializeSettings()
 {
     slotAvailableEngineChanged();
@@ -129,7 +138,7 @@ void TextToSpeechConfigWidget::writeConfig()
     settings.engineName = mAvailableEngine->currentData().toString();
     settings.voice = mVoice->currentVoice();
     // qDebug() << " save settings " << settings;
-    TextEditTextToSpeech::TextToSpeechUtil::writeConfig(std::move(settings));
+    TextEditTextToSpeech::TextToSpeechUtil::writeConfig(settings);
 }
 
 void TextToSpeechConfigWidget::slotLocalesAndVoices()
@@ -161,16 +170,20 @@ void TextToSpeechConfigWidget::restoreDefaults()
     // TODO load default value
 }
 
-void TextToSpeechConfigWidget::slotTestTextToSpeech()
+void TextToSpeechConfigWidget::slotTestTextToSpeech(bool checked)
 {
-    TextToSpeechConfigInterface::EngineSettings settings;
-    settings.rate = mRate->value();
-    settings.pitch = mPitch->value();
-    settings.volume = mVolume->value();
-    settings.localeName = mLanguage->currentData().toLocale().name();
-    settings.voice = mVoice->currentVoice();
-    qCDebug(TEXTEDITTEXTTOSPEECH_LOG) << " settings " << settings;
-    mTextToSpeechConfigInterface->testEngine(settings);
+    if (checked) {
+        TextToSpeechConfigInterface::EngineSettings settings;
+        settings.rate = mRate->value();
+        settings.pitch = mPitch->value();
+        settings.volume = mVolume->value();
+        settings.localeName = mLanguage->currentData().toLocale().name();
+        settings.voice = mVoice->currentVoice();
+        qCDebug(TEXTEDITTEXTTOSPEECH_LOG) << " settings " << settings;
+        mTextToSpeechConfigInterface->testEngine(settings);
+    } else {
+        mTextToSpeechConfigInterface->stop();
+    }
 }
 
 void TextToSpeechConfigWidget::updateAvailableEngine()
