@@ -1,11 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 #include "textedittexttospeech_export.h"
+#include <QTextToSpeech>
 #include <QWidget>
 class QComboBox;
 class QPushButton;
@@ -19,22 +20,38 @@ class TEXTEDITTEXTTOSPEECH_EXPORT TextToSpeechConfigWidget : public QWidget
 {
     Q_OBJECT
 public:
+    /*!
+     */
     explicit TextToSpeechConfigWidget(QWidget *parent = nullptr);
+    /*!
+     */
     ~TextToSpeechConfigWidget() override;
 
+    /*!
+     */
     void initializeSettings();
 
+    /*!
+     */
     void writeConfig();
+    /*!
+     */
     void readConfig();
 
+    /*!
+     */
     void setTextToSpeechConfigInterface(TextToSpeechConfigInterface *interface);
+    /*!
+     */
     void restoreDefaults();
 
 Q_SIGNALS:
+    /*!
+     */
     void configChanged(bool state);
 
 private:
-    TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotTestTextToSpeech();
+    TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotTestTextToSpeech(bool checked);
     TEXTEDITTEXTTOSPEECH_NO_EXPORT void valueChanged();
     TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotLocalesAndVoices();
     TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotUpdateSettings();
@@ -47,12 +64,13 @@ private:
     TEXTEDITTEXTTOSPEECH_NO_EXPORT void updateAvailableEngine();
     TEXTEDITTEXTTOSPEECH_NO_EXPORT void updateAvailableVoices();
     TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotAvailableEngineChanged();
+    TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotTextChanged(QTextToSpeech::State state);
     TextToSpeechSliderWidget *const mVolume;
     TextToSpeechSliderWidget *const mRate;
     TextToSpeechSliderWidget *const mPitch;
+    QComboBox *const mAvailableEngine;
     TextToSpeechLanguageComboBox *const mLanguage;
     TextToSpeechConfigInterface *mTextToSpeechConfigInterface = nullptr;
-    QComboBox *const mAvailableEngine;
     TextToSpeechVoiceComboBox *const mVoice;
     QPushButton *const mTestButton;
 };
