@@ -30,6 +30,11 @@ TextToSpeechInterface::TextToSpeechInterface(TextToSpeechWidget *textToSpeechWid
             &TextEditTextToSpeech::TextToSpeech::stateChanged,
             d->mTextToSpeechWidget,
             &TextEditTextToSpeech::TextToSpeechWidget::slotStateChanged);
+
+    connect(TextEditTextToSpeech::TextToSpeech::self(),
+            &TextEditTextToSpeech::TextToSpeech::aboutToSynthesize,
+            d->mTextToSpeechWidget,
+            &TextEditTextToSpeech::TextToSpeechWidget::aboutToSynthesize);
 }
 
 TextToSpeechInterface::~TextToSpeechInterface() = default;
@@ -40,10 +45,21 @@ bool TextToSpeechInterface::isReady() const
 }
 
 void TextToSpeechInterface::say(const QString &text)
+{
+    intializePlay();
+    TextEditTextToSpeech::TextToSpeech::self()->say(text);
+}
+
+void TextToSpeechInterface::intializePlay()
 {
     d->mTextToSpeechWidget->setState(TextEditTextToSpeech::TextToSpeechWidget::Play);
     d->mTextToSpeechWidget->showWidget();
-    TextEditTextToSpeech::TextToSpeech::self()->say(text);
+}
+
+qsizetype TextToSpeechInterface::enqueue(const QString &text)
+{
+    intializePlay();
+    return TextEditTextToSpeech::TextToSpeech::self()->enqueue(text);
 }
 
 double TextToSpeechInterface::volume() const
