@@ -5,7 +5,6 @@
 */
 
 #include "texttospeechwidget.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "texttospeechactions.h"
 #include "texttospeechconfigdialog.h"
@@ -22,6 +21,7 @@ using namespace Qt::Literals::StringLiterals;
 using namespace std::chrono_literals;
 #include <chrono>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace TextEditTextToSpeech;
 
 class Q_DECL_HIDDEN TextEditTextToSpeech::TextToSpeechWidgetPrivate
@@ -86,6 +86,7 @@ TextToSpeechWidget::TextToSpeechWidget(QWidget *parent)
     hbox->addWidget(d->mConfigureButton);
 
     d->mTextToSpeechInterface = new TextToSpeechInterface(this, this);
+    d->mTextToSpeechInterface->reloadSettings();
     applyVolume();
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
     hideWidget();
@@ -137,6 +138,19 @@ void TextToSpeechWidget::say(const QString &text)
     }
 }
 
+qsizetype TextToSpeechWidget::enqueue(const QString &text)
+{
+    qsizetype index = -1;
+    if (!text.isEmpty()) {
+        if (d->mTextToSpeechInterface->isReady()) {
+            index = d->mTextToSpeechInterface->enqueue(text);
+        } else {
+            KMessageBox::error(this, i18n("Engine has a problem."), i18nc("@title:window", "Text To Speech"));
+        }
+    }
+    return index;
+}
+
 TextToSpeechWidget::State TextToSpeechWidget::state() const
 {
     return d->mTextToSpeechActions->state();
