@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,11 +16,19 @@ namespace TextEmoticonsCore
  */
 class TEXTEMOTICONSCORE_EXPORT CustomEmojiIconManager : public QObject
 {
-    Q_GADGET
+    Q_OBJECT
 public:
+    /*!
+     */
     explicit CustomEmojiIconManager(QObject *parent = nullptr);
-    virtual ~CustomEmojiIconManager();
+    /*!
+     */
+    ~CustomEmojiIconManager() override;
+    /*!
+     */
     virtual QIcon generateIcon(const QString &customIdentifier);
+    /*!
+     */
     virtual QString fileName(const QString &customIdentifier);
 };
 }
