@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,22 +15,36 @@ namespace TextGrammarCheck
 {
 class LanguageToolComboBox;
 class LanguageToolUpdateComboBox;
+/**
+ * @brief The LanguageToolConfigWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class TEXTGRAMMARCHECK_EXPORT LanguageToolConfigWidget : public QWidget
 {
     Q_OBJECT
 public:
+    /*!
+     */
     explicit LanguageToolConfigWidget(QWidget *parent = nullptr);
+    /*!
+     */
     ~LanguageToolConfigWidget() override;
+    /*!
+     */
     void loadSettings();
+    /*!
+     */
     void saveSettings();
 
 Q_SIGNALS:
+    /*!
+     */
     void resetValue();
 
 private:
     Q_DISABLE_COPY(LanguageToolConfigWidget)
-    void updateWidgets(bool enabled);
-    void slotResetValue();
+    TEXTGRAMMARCHECK_NO_EXPORT void updateWidgets(bool enabled);
+    TEXTGRAMMARCHECK_NO_EXPORT void slotResetValue();
     QCheckBox *const mUseLocalInstance;
     QLineEdit *const mInstancePath;
     QLabel *const mInstancePathLabel;
