@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -88,19 +88,39 @@ public:
         yi,
         lastLanguage = yi
     };
+    /*!
+     */
     void addItemToFromComboBox(QComboBox *combo, const QString &languageCode, const QString &translatedStr);
 
     // Only for test
-    Q_REQUIRED_RESULT static QMap<TranslatorUtil::Language, QString> translatedLanguages();
+    [[nodiscard]] static QMap<TranslatorUtil::Language, QString> translatedLanguages();
 
-    Q_REQUIRED_RESULT static QString loadEngine();
+    /*!
+     */
+    [[nodiscard]] static QString loadEngine();
+    /*!
+     */
     static void saveEngineSettings(const QString &engineName);
-    Q_REQUIRED_RESULT static QString groupTranslateName();
-    Q_REQUIRED_RESULT static QString engineTranslateName();
-    Q_REQUIRED_RESULT static QString defaultEngineName();
-    Q_REQUIRED_RESULT static QString translatedLanguage(TranslatorUtil::Language lang);
-    Q_REQUIRED_RESULT static QString languageCode(TranslatorUtil::Language lang);
-    Q_REQUIRED_RESULT static QString searchI18nFromLanguage(const QString &langCode);
-    Q_REQUIRED_RESULT static TranslatorUtil::Language stringToLanguage(const QString &str);
+    /*!
+     */
+    [[nodiscard]] static QString groupTranslateName();
+    /*!
+     */
+    [[nodiscard]] static QString engineTranslateName();
+    /*!
+     */
+    [[nodiscard]] static QString defaultEngineName();
+    /*!
+     */
+    [[nodiscard]] static QString translatedLanguage(TranslatorUtil::Language lang);
+    /*!
+     */
+    [[nodiscard]] static QString languageCode(TranslatorUtil::Language lang);
+    /*!
+     */
+    [[nodiscard]] static QString searchI18nFromLanguage(const QString &langCode);
+    /*!
+     */
+    [[nodiscard]] static TranslatorUtil::Language stringToLanguage(const QString &str);
 };
 }
