@@ -4,6 +4,8 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "lingvaengineutiltest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../lingvaengineutil.h"
 #include <QTest>
 QTEST_MAIN(LingvaEngineUtilTest)
@@ -14,8 +16,8 @@ LingvaEngineUtilTest::LingvaEngineUtilTest(QObject *parent)
 
 void LingvaEngineUtilTest::shouldHaveDefaultValues()
 {
-    QCOMPARE(LingvaEngineUtil::groupName(), QStringLiteral("LingvaTranslator"));
-    QCOMPARE(LingvaEngineUtil::serverUrlKey(), QStringLiteral("ServerUrl"));
+    QCOMPARE(LingvaEngineUtil::groupName(), u"LingvaTranslator"_s);
+    QCOMPARE(LingvaEngineUtil::serverUrlKey(), u"ServerUrl"_s);
 }
 
 #include "moc_lingvaengineutiltest.cpp"
