@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,11 +16,15 @@ class TranslatorConfigureWidget;
 class TEXTTRANSLATOR_EXPORT TranslatorConfigureDialog : public QDialog
 {
 public:
+    /*!
+     */
     explicit TranslatorConfigureDialog(QWidget *parent = nullptr);
+    /*!
+     */
     ~TranslatorConfigureDialog() override;
 
 private:
-    void slotAccept();
+    TEXTTRANSLATOR_NO_EXPORT void slotAccept();
     TranslatorConfigureWidget *const mTranslatorConfigureWidget;
 };
 }
